external

package
v1.30.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 29, 2026 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Overview

Package external contains the functions needed to manage servers which are external to this PostgreSQL cluster

Index

Constants

This section is empty.

Variables

var ErrInvalidPathComponent = errors.New("value cannot be used as a filesystem path component")

ErrInvalidPathComponent is returned when a value that is used as a filesystem path component contains a path separator or a parent-directory reference, both of which could be used to escape the external secrets directory.

Functions

func ConfigureConnectionToServer

func ConfigureConnectionToServer(
	ctx context.Context,
	client ctrl.Client,
	namespace string,
	server *apiv1.ExternalCluster,
) (string, error)

ConfigureConnectionToServer creates a connection string to the external server, using the configuration inside the cluster and dumping the secret when needed in a custom passfile. Returns a connection string or any error encountered

func GetServerConnectionString added in v1.21.4

func GetServerConnectionString(
	server *apiv1.ExternalCluster,
	databaseName string,
) (string, error)

GetServerConnectionString gets the connection string to be used to connect to this external server, without dumping the required cryptographic material

Types

This section is empty.

Directories

Path Synopsis
internal
pgpass
Package pgpass allows the user to generate a PostgreSQL .pgpass file See: https://www.postgresql.org/docs/current/libpq-pgpass.html
Package pgpass allows the user to generate a PostgreSQL .pgpass file See: https://www.postgresql.org/docs/current/libpq-pgpass.html

Jump to